propertySelector property

PropertySelector<T>? propertySelector
final

A function that returns the list of string properties to be matched against the search query.

This is mutually exclusive with customFilter. If both are provided, an assertion error will be thrown.

Implementation

final PropertySelector<T>? propertySelector;