search_config
library
Classes
-
SearchConfig<T>
-
A configuration class that defines how a searchable list behaves.
Typedefs
-
ItemBuilder<T>
= Widget Function(BuildContext context, T item, String query)
-
Signature for building the widget representation of each item in the list.
-
ItemFilter<T>
= bool Function(T item, String query)
-
Signature for defining custom filtering logic for search.
-
OnItemSelected<T>
= void Function(T item)
-
Signature for the callback when an item is selected.
-
PropertySelector<T>
= List<String> Function(T item)
-
Signature for selecting searchable string properties from an item.
For example: extracting
name and email from a user model.