SearchConfig<T> class
Constructors
-
SearchConfig({required List<
T> items, required ItemBuilder<T> itemBuilder, PropertySelector<T> ? propertySelector, ItemFilter<T> ? customFilter, String searchFieldLabel = 'Search...', Widget? noResultsWidget, OnItemSelected<T> ? onItemSelected})
Properties
-
customFilter
→ ItemFilter<
T> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
itemBuilder
→ ItemBuilder<
T> -
final
-
items
→ List<
T> -
final
- noResultsWidget → Widget?
-
final
-
onItemSelected
→ OnItemSelected<
T> ? -
final
-
propertySelector
→ PropertySelector<
T> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchFieldLabel → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited